@@ -6,6 +6,11 @@ INIT { Test::Class->runtests }
 
 sub parent { ['Test::Class'] }
 
+sub startup  : Tests(startup)  {}
+sub setup    : Tests(setup)    {}
+sub teardown : Tests(teardown) {}
+sub shutdown : Tests(shutdown) {}
+
 sub sanity : Tests(2) {
     my $test = shift;
 
